//-----------------------------------------------------------------------------
// Copyright  2000 - Philip Howard - All rights reserved
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//-----------------------------------------------------------------------------
// package	avlmap
// homepage	http://phil.ipal.org/freeware/
//-----------------------------------------------------------------------------
// author	Philip Howard
// email	phil@ipal.org
// homepage	http://phil.ipal.org/
//-----------------------------------------------------------------------------
// This file is best viewed using a fixed spaced font such as Courier
// and in a display at least 112 columns wide.
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// file		map_str.c
//
// purpose	Define functions for the key and data type specified by
//		the source file that includes this file.
//-----------------------------------------------------------------------------

#include <string.h>
#include "map_lib.h"

//-----------------------------------------------------------------------------
// function	map_str_put
//
// purpose	Put a string indexed by a string in a mapping with both
//		the key and data in the same function.
//
// arguments	1 (MAP) mapping handle
//		2 (const char *) key string
//		3 (const char *) data string
//
// returns	(int) -2 = error, no map
//		(int)  0 = data inserted or replaced
//-----------------------------------------------------------------------------
int
map_str_put (
    MAP			arg_map
    ,
    const char *	arg_key_str
    ,
    const char *	arg_data_str
)
{
    return
	map_str_insert( arg_map, arg_key_str ) < 0
	? -2
	: map_str_store( arg_map, arg_data_str );
}

//-----------------------------------------------------------------------------
// function	map_str_get_dup
//
// purpose	Get a string indexed by a string from a mapping with both
//		the key and the data in the same function.  Return a
//		duplicate of the string that the caller must free.
//
// arguments	1 (MAP) mapping handle
//		2 (const char *) key string
//		3 (const char *) default data string
//
// returns	(char *) duplicate data string or duplicate of default data
//-----------------------------------------------------------------------------
char *
map_str_get_dup (
    MAP			arg_map
    ,
    const char *	arg_key_str
    ,
    const char *	arg_default_str
)
{
    return
	map_str_find( arg_map, arg_key_str, 0 ) == MAP_DATA_CS
	? map_str_fetch_dup( arg_map, NULL )
	: arg_default_str ? strdup( arg_default_str ) : NULL;
}

//-----------------------------------------------------------------------------
// function	map_str_get_ptr
//
// purpose	Get a string indexed by a string from a mapping with both
//		the key and the data in the same function.  Return a
//		pointer to the string that the caller must not change.
//
// arguments	1 (MAP) mapping handle
//		2 (const char *) key string
//		3 (const char *) default data string
//
// returns	(const char *) data string pointer or default data pointer
//-----------------------------------------------------------------------------
const char *
map_str_get_ptr (
    MAP			arg_map
    ,
    const char *	arg_key_str
    ,
    const char *	arg_default_str
)
{
    return
	map_str_find( arg_map, arg_key_str, 0 ) == MAP_DATA_CS
	? map_str_fetch_ptr( arg_map, NULL )
	: arg_default_str;
}
